@@ -53,22 +53,6 @@ class ParameterTypeError(Exception):
     pass
 
 
-@deprecate("This function is no longer used and will be removed soon.")
-def is_number(thing: Any) -> bool:
-    """
-    Test if an object can be converted to a float UNLESS it is a string or
-    complex.
-    """
-    if isinstance(thing, (str, complex, np.complex,
-                          np.complex128, np.complex64)):
-        return False
-    try:
-        float(thing)
-        return True
-    except (ValueError, TypeError):
-        return False
-
-
 class DataSaver:
     """
     The class used by the :class:`Runner` context manager to handle the
@@ -358,7 +342,7 @@ class DataSaver:
 
     @staticmethod
     def _validate_result_types(
-            results_dict: Dict[ParamSpecBase, np.ndarray]) -> None:
+            results_dict: Mapping[ParamSpecBase, np.ndarray]) -> None:
         """
         Validate the type of the results
         """
@@ -573,7 +557,7 @@ class Runner:
     to the database. Additionally, it may perform experiment bootstrapping
     and clean-up after a measurement.
     """
-
+    _is_entered: bool = False
     def __init__(
             self, enteractions: List, exitactions: List,
             experiment: Experiment = None, station: Station = None,
@@ -583,7 +567,7 @@ class Runner:
             subscribers: Sequence[Tuple[Callable,
                                         Union[MutableSequence,
                                               MutableMapping]]] = None,
-            parent_datasets: List[Dict] = [],
+            parent_datasets: Sequence[Dict] = (),
             extra_log_info: str = '',
             write_in_background: bool = False) -> None:
 
@@ -591,6 +575,7 @@ class Runner:
             warnings.warn(f"The specified write period of {write_period} s "
                           "will be ignored, since write_in_background==True")
 
+
         self.enteractions = enteractions
         self.exitactions = exitactions
         self.subscribers: Sequence[Tuple[Callable,
@@ -617,6 +602,13 @@ class Runner:
     def __enter__(self) -> DataSaver:
         # TODO: should user actions really precede the dataset?
         # first do whatever bootstrapping the user specified
+
+        if Runner._is_entered:
+            log.warning('Nested measurements are not supported. This will '
+                        'become an error in future releases of QCoDeS')
+
+        Runner._is_entered = True
+
         for func, args in self.enteractions:
             func(*args)
 
@@ -678,6 +670,7 @@ class Runner:
         with DelayedKeyboardInterrupt():
             self.datasaver.flush_data_to_database()
 
+            Runner._is_entered = False
             # perform the "teardown" events
             for func, args in self.exitactions:
                 func(*args)
